#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.

"""Centralized setup for GObject Introspection (GI) in Cthulhu."""

from gi.repository import Peas
import gi

# FIRST: Load GIRepository with the correct version
# This is critical: get GIRepository loaded BEFORE anything else
try:
    gi.require_version('GIRepository', '3.0')
    from gi.repository import GIRepository
except (ValueError, ImportError):
    try:
        gi.require_version('GIRepository', '2.0')
        from gi.repository import GIRepository
    except (ValueError, ImportError):
        print("WARNING: Could not load GIRepository with either version 2.0 or 3.0")

# SECOND: Set versions for other modules and import them
gi.require_version('Atspi', '2.0')
gi.require_version('Gdk', '3.0')

try:
    from gi.repository import GObject
except ImportError:
    GObject = None

try:
    from gi.repository import Atspi
except ImportError:
    Atspi = None

try:
    from gi.repository import Gdk
except ImportError:
    Gdk = None

try:
    gi.require_version('Gio', '2.0')
    from gi.repository import Gio
except (ValueError, ImportError):
    Gio = None

# Export all the imported modules
__all__ = ['gi', 'GObject', 'Atspi', 'Gdk', 'Peas', 'Gio', 'GIRepository']
